@@ -4,7 +4,7 @@
     General purpose toolkit library
     In order to use this library, your have to do either of the following:
 
-    1). Install the library. (recommended)
+    1). Install the library via pip. (recommended)
         pip install toolkit_library
 
     2). Install the library.
@@ -20,3 +20,5 @@
 
     For more working examples, please refer to tests.py
 """
+__version__ = '0.3.1'
+__author__ = 'Tyler Long'
